IntoCategories

Trait IntoCategories 

pub trait IntoCategories {
    // Required method
    fn into_categories(self) -> Categories;
}
Trait for types that can be converted into Categories.

Required Methods

fn into_categories(self) -> Categories

Converts this value into Categories.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IntoCategories for &Series

Source

fn into_categories(self) -> Categories

Converts a borrowed Polars string Series into plotkit Categories. Null values become the string "null".

Source

impl IntoCategories for &[&str]

Source

fn into_categories(self) -> Categories

Converts a slice of string slices into Categories.

Source

impl IntoCategories for &[String]

Source

fn into_categories(self) -> Categories

Clones the string slice into Categories.

Source

impl IntoCategories for Vec<&str>

Source

fn into_categories(self) -> Categories

Converts a vector of string slices into Categories.

Source

impl IntoCategories for Vec<String>

Source

fn into_categories(self) -> Categories

Zero-copy conversion from an owned Vec<String>.

Implementors